# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-LeakTrace
Summary:	Trace memory leaks
Version:	0.17
Release:	11.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-LeakTrace
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-LeakTrace-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Builder::Module)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(autouse)
BuildRequires:	perl(Class::Struct)
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Test::More) >= 0.62
BuildRequires:	perl(threads)
# Extra Tests
%if 0%{?!perl_bootstrap:1}
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Spellunker)
BuildRequires:	perl(Test::Synopsis)
BuildRequires:	perl(Test::Valgrind)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't provide private perl libs
%{?perl_default_filter}

%description
Test::LeakTrace provides several functions that trace memory leaks. This module
scans arenas, the memory allocation system, so it can detect any leaked SVs in
given blocks.

Leaked SVs are SVs that are not released after the end of the scope they have
been created. These SVs include global variables and internal caches. For
example, if you call a method in a tracing block, perl might prepare a cache
for the method. Thus, to trace true leaks, no_leaks_ok() and leaks_cmp_ok()
executes a block more than once.

%prep
%setup -q -n Test-LeakTrace-%{version}

# Remove redundant exec bits
chmod -c -x lib/Test/LeakTrace/Script.pm t/lib/foo.pl

# Fix up shellbangs in doc scripts
sed -i -e 's|^#!perl|#!/usr/bin/perl|' benchmark/*.pl example/*.{pl,t} {t,xt}/*.t

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{?!perl_bootstrap:1}
make test TEST_FILES="$(echo xt/*.t)"
%endif

%files
%doc Changes README benchmark/ example/ t/ xt/
%{perl_vendorarch}/auto/Test/
%{perl_vendorarch}/Test/
%{_mandir}/man3/Test::LeakTrace.3*
%{_mandir}/man3/Test::LeakTrace::JA.3*
%{_mandir}/man3/Test::LeakTrace::Script.3*

%changelog
* Fri Mar 31 2023 Paul Howarth <paul@city-fan.org> - 0.17-11
- Use SPDX-format license tag

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 0.17-7
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.17-3
- Perl 5.34 rebuild

* Tue Jan  5 2021 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Point issue tracker at GitHub
- Unconditionally include tests as documentation

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 0.16-16
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 0.16-12
- Perl 5.30 rebuild

* Tue Apr  2 2019 Paul Howarth <paul@city-fan.org> - 0.16-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 0.16-7
- Perl 5.28 rebuild

* Sun Aug  6 2017 Paul Howarth <paul@city-fan.org> - 0.16-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sun Jun 18 2017 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - Fix build and test issues with perl5.26 due to removal of . from @INC
    (CPAN RT#120420, GH#3)
- This release by LEEJO → update source URL

* Sun Jun  4 2017 Paul Howarth <paul@city-fan.org> - 0.15-11
- Fix build without '.' in @INC (CPAN RT#120420)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Mon Oct  3 2016 Paul Howarth <paul@city-fan.org> - 0.15-9
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Nov 14 2014 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Fix test failure on Windows
    (https://github.com/gfx/p5-Test-LeakTrace/pull/1)
- Classify buildreqs by usage
- Drop obsoletes/provides for old tests sub-package

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 0.14-11
- Perl 5.20 rebuild

* Wed Sep 18 2013 Paul Howarth <paul@city-fan.org> - 0.14-7
- Don't run the extra tests when bootstrapping

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.14-6
- Perl 5.18 rebuild

* Mon Jul  9 2012 Paul Howarth <paul@city-fan.org> - 0.14-4
- BR: perl(autouse), perl(base), perl(Carp), perl(constant), perl(Cwd),
  perl(Data::Dumper), perl(File::Path), perl(threads) and perl(XSLoader)

* Tue Mar 13 2012 Paul Howarth <paul@city-fan.org> - 0.14-3
- BR: perl(Test::Valgrind) for additional test coverage

* Mon Mar 12 2012 Paul Howarth <paul@city-fan.org> - 0.14-2
- Use %%{optflags}
- BR: perl(ExtUtils::MakeMaker)
- Don't need to remove empty directories from buildroot
- Ship the test suite as %%doc (as long as we have %%{perl_default_filter} to
  prevent doc-file dependencies), and add provides/obsoletes for the tests
  subpackage that the Fedora version used to ship
- Drop perl ≥ 5.8.1 buildreq; this is satisfied by all supported distributions
- Drop %%defattr, redundant since rpm 4.4

* Fri Oct  7 2011 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Fix Test::Valgrind failures
- Run main test suite and release tests separately
- Skip xt/05_valgrind.t as we don't have Test::Valgrind yet
- Drop spell-check test patch and just move JA.pod out of the way when doing
  the spell check as it generates false positives with old hunspell versions

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 0.13-3
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 0.13-2
- Use %%{_fixperms} macro rather than our own chmod incantation
- Nobody else likes macros for commands

* Mon Aug  2 2010 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Use ">= 0", instead of "== 0" for no_leaks_ok()
  - Add count_sv() to count all the SVs in a perl interpreter
  - Fix tests for older perls

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.11-2
- Rebuild for perl 5.12.1 in Rawhide

* Mon Jun 14 2010 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11 (fix false-positive related to XS code - CPAN RT #58133)
- Permissions now sensible on lib/Test/LeakTrace.pm

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.10-3
- Fix dist tag for RHEL-6 Beta

* Thu Feb 11 2010 Paul Howarth <paul@city-fan.org> - 0.10-2
- Filter provides for private perl shared objects
- Fix spelling check

* Fri Nov 27 2009 Paul Howarth <paul@city-fan.org> - 0.10-1
- Initial RPM version
